##  Production Workspace Best Practices
Here are common scenarios and use cases that are recommended to be implemented directly in the production workspace, along with reasons why testing them in a sandbox is unnecessary:
  * Onboarding and Training
SAP LeanIX's user interface ensures that users are fully aware of any changes they make to fact sheet data. With clear Edit, Add, and Save buttons, it’s easy for users to see when changes are being applied. This helps prevent mistakes, especially by inexperienced users, when working with fact sheets, reports, diagrams, and other features. All changes are logged, visible to all users, and can be easily reviewed and reverted if needed.
Introducing SAP LeanIX is more effective when using live data that users are already familiar with. If you want users new to SAP LeanIX to create new fact sheets and you doubt the initial data quality, a best practice is to leverage the draft status of fact sheets before they are included in reports after approval. Additionally, assigning at least one responsible user as a subscriber to each fact sheet offers several benefits, such as automatic notifications about changes, which helps maintain and monitor data quality. To learn more, see [Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD "Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.") and [Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet subscription assigns responsibility and accountability to users for maintaining data. Learn about fact sheet subscriptions, including types, roles, and how to assign and subscribe to fact sheets to promote stakeholder involvement and ensure data accuracy and completeness.").
  * Hiding Data
Logically segregating sensitive data into different workspaces for security reasons is unnecessary, as virtual workspace configurations in the production workspace let you define which data is visible to different users while they all benefit from using the latest data in the same workspace. To learn more, see [Virtual Workspaces](https://help.sap.com/docs/leanix/ea/virtual-workspaces?locale=en-US&state=PRODUCTION&version=CLOUD "Manage access to fact sheets for custom user groups").
  * Meta Model Configuration
SAP LeanIX provides the means to safely and efficiently apply meta model configurations on production workspaces and test them before exposing them to users. The visibility of fact sheets and their attributes can be limited to admin users before making them visible and editable for members. As a best practice, focus on a small scope of meta model changes and introduce them iteratively with a quick turnaround time of validating their value.
  * New Dashboards, Diagrams, and Reports
Access permissions for dashboards, diagrams, and reports can be set individually. These can remain private to the creator until they decide they are ready to be made visible to other users.
  * Importing Fact Sheet Data Through Excel File
When importing, the spreadsheet's content is validated before any data is added to or changed in the workspace. Before the users confirm the import, a summary of the changes is shown with details on fact sheet data (e.g., the number of new and changed fact sheets), ensuring accuracy and data integrity. For more, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
  * Surveys
Surveys have a dedicated test run for creators to help survey creators check whether the content meets their intent.
  * OData Integration
Since this integration only reads data from a saved search in the workspace, configuring it directly in a live workspace poses no risk. It's helpful to create a dedicated saved search for the initial setup of the integration.
  * Automations
Automations are triggered by activities or changes to fact sheets, and not by existing data on the fact sheets. This means that even if an automation is set up incorrectly, it won’t make irreversible changes. General advice for automation is to start small by adding a condition based on a tag on a limited set of fact sheets to test the result. Changes from automations are visible in the audit log, showing them as performed by the technical user "LeanIX Default." For more, see [Automations](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD "Configure no-code automations to streamline your workflows.").
